@@ -160,7 +160,7 @@ class ShippingBillingViewTestCase(TestCase):
     def test_cart_required_redirects_on_checkout(self):
         resp = self.client.get(reverse('checkout_selection'))
         self.assertEqual(resp.status_code, 302)
-        self.assertEqual('http://testserver/', resp._headers['location'][1])
+        self.assertEqual('http://testserver/shop/cart/', resp._headers['location'][1])
 
 
 class ShippingBillingViewOrderStuffTestCase(TestCase):
@@ -230,6 +230,8 @@ class CheckoutCartToOrderTestCase(TestCase):
         setattr(self.request, 'user', self.user)
         setattr(self.request, 'session', {})
         setattr(self.request, 'method', 'GET')
+        self.product = Product(name='pizza', slug='pizza', unit_price='1.45')
+        self.product.save()
         self.cart = Cart()
         self.cart.user = self.user
         self.cart.save()
@@ -239,6 +241,19 @@ class CheckoutCartToOrderTestCase(TestCase):
         res = view.create_order_object_from_cart()
         self.assertEqual(res.order_total, Decimal('0'))
 
+    def test_orders_are_created_and_cleaned_up(self):
+        view = CheckoutSelectionView(request=self.request)
+        # create a new order with pk 1
+        old_order = view.create_order_object_from_cart()
+        # create order with pk 2 so sqlite doesn't reuse pk 1
+        Order.objects.create()
+        # then create a different new order, from a different cart with pk 3
+        # order pk 1 should be deleted here
+        self.cart.add_product(self.product)
+        new_order = view.create_order_object_from_cart()
+        self.assertFalse(Order.objects.filter(pk=old_order.pk).exists()) # check it was deleted
+        self.assertNotEqual(old_order.order_total, new_order.order_total)
+
     def test_processing_signal(self):
         view = CheckoutSelectionView(request=self.request)
 
